<div align="center">

# wordle*bee* 🐝

[![PyPi Version](https://img.shields.io/pypi/v/wordlebee.svg?style=flat-square)](https://pypi.org/project/wordlebee/)
[![License](https://img.shields.io/badge/license-MIT-blue?style=flat-square)](#license)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg?style=flat-square)](#black)
</div>

A cli wordle word guessing helper bee to solve the wordle puzzle of the day.

[![asciicast](https://asciinema.org/a/NSZZUpGhajLcDh9xuMGYIDjTs.svg)](https://asciinema.org/a/NSZZUpGhajLcDh9xuMGYIDjTs?t=8)

## Usage

    python -m wordlebee

## Installation

Install `wordlebee`:

    pip install wordlebee

## Development

Install conda enviroment:

    conda env create -f environment.yml

Install using `poetry`:

    poetry install
